import { PackageLock } from './package-lock-parser';
import { YarnLock } from './yarn-lock-parse';
export interface Dep {
    name: string;
    version: string;
    dev?: boolean;
}
export interface ManifestFile {
    name: string;
    dependencies?: {
        [dep: string]: string;
    };
    devDependencies?: {
        [dep: string]: string;
    };
    version?: string;
}
export interface PkgTree {
    name: string;
    version: string;
    dependencies: {
        [dep: string]: PkgTree;
    };
    depType?: DepType;
    hasDevDependencies?: boolean;
    cyclic?: boolean;
}
export declare enum DepType {
    prod = "prod",
    dev = "dev"
}
export declare enum LockfileType {
    npm = "npm",
    yarn = "yarn"
}
export interface LockfileParser {
    parseLockFile: (lockFileContents: string) => Lockfile;
    getDependencyTree: (manifestFile: ManifestFile, lockfile: Lockfile, includeDev?: boolean) => Promise<PkgTree>;
}
export declare type Lockfile = PackageLock | YarnLock;
export declare function parseManifestFile(manifestFileContents: string): ManifestFile;
export declare function getTopLevelDeps(targetFile: ManifestFile, includeDev: boolean): Dep[];
export declare function createPkgTreeFromDep(dep: Dep): PkgTree;
